//---------------

//+------------------------------------------------------------------+
//| Rob_Ea.mq4 |
//| Rob Cousins |
//| |
//+------------------------------------------------------------------+
#property copyright "Rob Cousins"
#property link ""

#define MAGICMA 20090216

//---- input parameters
extern double Lots;
extern int Short_MA=5;
extern int Long_MA=15;
extern double Stoch_Upper=70.0;
extern double Stoch_Lower=30.0;
extern double RSI_Upper=80.0;
extern double RSI_Lower=20.0;
//+------------------------------------------------------------------+
//| expert initialization function |
//+------------------------------------------------------------------+
int init()
{
//----

//----
return(0);
}
//+------------------------------------------------------------------+
//| expert deinitialization function |
//+------------------------------------------------------------------+
int deinit()
{
//----

//----
return(0);
}

string Current_Indication()
{

// Moving Average variables
double MA_Short;
double MA_Long;
string Current_MA_Indicator;
string Previous_MA_Indicator;
string MA_Indicator;


// Stochastic Variables
string Current_Stoch_Indicator;
string Previous_Stoch_Indicator;
string Stoch_Indicator;

// RSI Variables
string Current_RSI_Indicator;
string Previous_RSI_Indicator;
string RSI_Indicator;

// --------------------------------------
// first get MAs and check for a MA Cross
// --------------------------------------

MA_Short=iMA(NULL,0,Short_MA,0,1,PRICE_MEDIAN,0);
MA_Long=iMA(NULL,0,Long_MA,0,0,PRICE_MEDIAN,0);

if (MA_Short>MA_Long) Current_MA_Indicator="BUY";
if (MA_Short<MA_Long) Current_MA_Indicator="SELL";

// set the previous and current value using the shifted MA (the last '1' in the options)

if (iMA(NULL,0,Short_MA,0,1,PRICE_MEDIAN,1)>iMA(NULL, 0,Long_MA,0,0,PRICE_MEDIAN,1)) Previous_MA_Indicator="BUY";
if (iMA(NULL,0,Short_MA,0,1,PRICE_MEDIAN,1)<iMA(NULL, 0,Long_MA,0,0,PRICE_MEDIAN,1)) Previous_MA_Indicator="SELL";

if ((Current_MA_Indicator=="BUY") && (Previous_MA_Indicator=="BUY")) MA_Indicator="BUY";
if ((Current_MA_Indicator=="SELL") && (Previous_MA_Indicator=="SELL")) MA_Indicator="SELL";


// ----------------------------
// Stochastic Indicator check
// ----------------------------

if(iStochastic(NULL,0,6,3,3,MODE_SMA,0,MODE_MAIN,0 )>Stoch_Upper) Current_Stoch_Indicator="BUY";
if(iStochastic(NULL,0,6,3,3,MODE_SMA,0,MODE_MAIN,0 )<Stoch_Lower) Current_Stoch_Indicator="SELL";

if(iStochastic(NULL,0,6,3,3,MODE_SMA,0,MODE_MAIN,1 )>Stoch_Upper) Previous_Stoch_Indicator="BUY";
if(iStochastic(NULL,0,6,3,3,MODE_SMA,0,MODE_MAIN,1 )<Stoch_Lower) Previous_Stoch_Indicator="SELL";

if ((Current_Stoch_Indicator=="BUY") && (Previous_Stoch_Indicator=="BUY")) Stoch_Indicator="BUY";
if ((Current_Stoch_Indicator=="SELL") && (Previous_Stoch_Indicator=="SELL")) Stoch_Indicator="SELL";


// ----------------------------
// RSI Indicator check
// ----------------------------

if(iRSI(NULL,0,3,PRICE_CLOSE,0)>RSI_Upper) Current_RSI_Indicator="BUY";
if(iRSI(NULL,0,3,PRICE_CLOSE,0)<RSI_Lower) Current_RSI_Indicator="SELL";

if(iRSI(NULL,0,3,PRICE_CLOSE,1)>RSI_Upper) Previous_RSI_Indicator="BUY";
if(iRSI(NULL,0,3,PRICE_CLOSE,1)<RSI_Lower) Previous_RSI_Indicator="SELL";

if ((Current_RSI_Indicator=="BUY") && (Previous_RSI_Indicator=="BUY")) RSI_Indicator="BUY";
if ((Current_RSI_Indicator=="SELL") && (Previous_RSI_Indicator=="SELL")) RSI_Indicator="SELL";


//----------------------------------------
// Figure out if you're in a buy or sell situation
//----------------------------------------

if((MA_Indicator=="BUY") && (Stoch_Indicator=="BUY") && (RSI_Indicator=="BUY")) return("BUY");
if((MA_Indicator=="SELL") && (Stoch_Indicator=="SELL") && (RSI_Indicator=="SELL")) return("SELL");


}



//+------------------------------------------------------------------+
//| Calculate open positions |
//+------------------------------------------------------------------+
string Current_Trade(string symbol)
{

//----
for(int i=0;i<OrdersTotal();i++)
{
if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false ) 
{
return ("NONE");
break;
}
if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
{
if(OrderType()==OP_BUY) return("BUY");
if(OrderType()==OP_SELL) return("SELL");
}
}

}


//----------------------------------------------------------------------
// If the signal has changed direction the first thing to do is Close
// the current open trade before opening another.
//-----------------------------------------------------------------------

void CloseTrade(string symbol)

{
// double ma;
//---- go trading only for first tiks of new bar
// if(Volume[0]>1) return;

//----
for(int i=0;i<OrdersTotal();i++)
{
if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false ) break; // there are no open trades
if(OrderMagicNumber()!=MAGICMA || OrderSymbol()!=Symbol()) continue;
//---- check order type 
// leaving both options for the moment in case I want to do it differently
// eg have a different colour, or whatever. Otherwise the two commands are the same
// and you'd only need one. Except the different prices I suppose... Doh!

if(OrderType()==OP_BUY)
{
OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
break;
}
if(OrderType()==OP_SELL)
{
OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
break;
}
}
//----
}


//-----------------------------------------------------------
// Open a position if that's what the tea leaves say
//------------------------------------------------------------

void OpenTrade(string symbol,string Type)
{

int res;

//---- buy conditions
if(Type=="BUY") OrderSend(Symbol(),OP_BUY,Lots,Ask,3,0,0,"ROB EA TEST",MAGICMA,0,Blue);

//---- sell conditions
if(Type=="SELL") OrderSend(Symbol(),OP_SELL,Lots,Bid,3,0,0,"ROB EA TEST",MAGICMA,0,Red);

}





//+------------------------------------------------------------------+
//| expert start function |
//+------------------------------------------------------------------+


void start()
{
//----
//---- calculate open orders by current symbol

//--- If there are no open trades, then simply open one...

if(Current_Trade(Symbol())=="NONE") OpenTrade(Symbol(),Current_Indication());

// But if there is an open trade we need to close it first before opening the new one.

if ((Current_Trade(Symbol())=="BUY") && (Current_Indication()=="SELL"))
{
CloseTrade(Symbol());
OpenTrade(Symbol(),Current_Indication()); 
}
if ((Current_Trade(Symbol())=="SELL") && (Current_Indication()=="BUY"))
{
CloseTrade(Symbol());
OpenTrade(Symbol(),Current_Indication()); 
}
return;

}

